@@ -1145,6 +1145,7 @@ impl<'a> Browser<'a> {
 mod tests {
     use super::*;
 
+    #[cfg(not(feature = "gh-actions"))]
     #[test]
     // An issue with submodules, see: https://github.com/radicle-dev/radicle-surf/issues/54
     fn test_submodule_failure() {
@@ -1488,6 +1489,7 @@ mod tests {
         }
 
         #[test]
+        #[cfg(not(windows))]
         fn can_get_last_commit_for_special_filenames() {
             let repo = Repository::new("./data/git-platinum")
                 .expect("Could not retrieve ./data/git-platinum as git repository");
@@ -1596,7 +1598,8 @@ mod tests {
                                 LineDiff::addition(b"[`radicle-surf`](https://github.com/radicle-dev/git-platinum) unit tests.\n".to_vec(), 2),
                             ]
                         }]
-                    }
+                    },
+                    eof: None,
                 }]
             };
             assert_eq!(expected_diff, diff);
@@ -1631,10 +1634,12 @@ mod tests {
                                 LineDiff::context(b"\n".to_vec(), 3, 4),
                             ]
                         }]
-                    }
+                    },
+                    eof: None,
                 }]
             };
 
+            let eof: Option<u8> = None;
             let json = serde_json::json!({
                 "created": ["LICENSE"],
                 "deleted": [],
@@ -1665,7 +1670,8 @@ mod tests {
                                 }
                             ]
                         }]
-                    }
+                    },
+                    "eof" : eof,
                 }]
             });
             assert_eq!(serde_json::to_value(&diff).unwrap(), json);
